@@ -71,7 +71,7 @@
 #include <KFindDialog>
 #include <KStatusBar>
 #include <KService>
-#include <KServiceTypeTrader>
+#include <KMimeTypeTrader>
 #include <KLineEdit>
 #include <KMimeType>
 #include <KShortcut>
@@ -392,7 +392,7 @@ KeysManager::KeysManager(QWidget *parent)
     connect(keysList2, SIGNAL(selectionChanged ()), this, SLOT(checkList()));
     connect(keysList2, SIGNAL(contextMenuRequested(Q3ListViewItem *, const QPoint &, int)), this, SLOT(slotMenu(Q3ListViewItem *, const QPoint &, int)));
     connect(keysList2, SIGNAL(destroyed()), this, SLOT(annule()));
-    connect(photoProps, SIGNAL(activated(int)), this, SLOT(slotSetPhotoSize(int)));
+    connect(photoProps, SIGNAL(triggered(int)), this, SLOT(slotSetPhotoSize(int)));
 
     // get all keys data
     setupGUI(KXmlGuiWindow::Create | Save | ToolBar | StatusBar | Keys, "keysmanager.rc");
@@ -895,7 +895,7 @@ void KeysManager::slotDeletePhoto()
     */
 
     KgpgInterface *interface = new KgpgInterface();
-    connect(interface, SIGNAL(delPhotoFinished(int, KgpgInterface*)), this, SLOT(slotDelPhotoFinished(int, KgpgInterface*)));
+    connect(interface, SIGNAL(delelePhotoFinished(int, KgpgInterface*)), this, SLOT(slotDelPhotoFinished(int, KgpgInterface*)));
     interface->deletePhoto(parent->keyId(), item->text(6));
 }
 
@@ -1630,7 +1630,9 @@ void KeysManager::showKeyInfo(const QString &keyID)
 
 void KeysManager::slotShowPhoto()
 {
-    KService::List list = KServiceTypeTrader::self()->query("image/jpeg", "Type == 'Application'");
+    KService::List list = KMimeTypeTrader::self()->query("image/jpeg");
+    if (list.isEmpty())
+       return;
     KeyListViewItem *item = keysList2->currentItem()->parent();
     KService::Ptr ptr = list.first();
     //KMessageBox::sorry(0,ptr->desktopEntryName());
@@ -1937,7 +1939,7 @@ void KeysManager::signkey()
     if (signList.count() == 1)
     {
         KeyListViewItem *item = keysList2->currentItem();
-        QString fingervalue = item->getKey()->fingerprint();
+        QString fingervalue = item->getKey()->fingerprintBeautified();
         QString opt;
 
         opt = i18n("<qt>You are about to sign key:<br /><br />%1<br />ID: %2<br />Fingerprint: <br /><b>%3</b>.<br /><br />"
